| rasch_logit | R Documentation |
Compute Logit and Row Means
rasch_logit(prob_matrix)
prob_matrix |
The matrix returned by compute_Modified_probabilities. |
A numeric matrix of logit transformations (log-odds) with dimensions
nrow(prob_matrix) rows by ncol(prob_matrix) + 1 columns.
The first columns contain the logit values for each item, and the final
column, named Row_Mean_Logit, contains the mean logit across all
items for each person, which serves as an estimate of Student Ability.
set.seed(123)
sample_data <- matrix(sample(c(0, 1), 100, replace = TRUE), ncol = 10)
prepared <- prepare_data(sample_data)
irt_results <- fit_binary_irt(prepared$matrix, prepared$total_score)
probs <- compute_Modified_probabilities(irt_results, prepared$total_score)
logit_results <- rasch_logit(probs)
print(head(logit_results))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.